@@ -1,5 +1,5 @@
 ;;; emacspeak-advice.el --- Advice all core Emacs functionality to speak intelligently
-;;; $Id: emacspeak-advice.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-advice.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Core advice forms that make emacspeak work
 ;;; Keywords: Emacspeak, Speech, Advice, Spoken  output
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -632,6 +632,9 @@ before the message is spoken.")
     (dtk-pause)
     (emacspeak-auditory-icon 'warn-user)
     (dtk-speak (apply 'format  (ad-get-args 0)))))
+(defadvice eval-minibuffer (before emacspeak pre act com)
+  "Speak the prompt"
+  (dtk-speak (ad-get-arg 0)))
 
 (defadvice read-from-minibuffer (around emacspeak pre act)
   "Prompt using speech as well. "
@@ -975,6 +978,103 @@ in completion buffers"
 ;;}}}
 ;;{{{  Advice comint:
 
+(defadvice comint-delchar-or-maybe-eof (around emacspeak pre act)
+  "Speak character you're deleting"
+  (cond
+   ((interactive-p )
+    (cond
+     ((= (point) (point-max))
+    (message "Sending EOF to comint process"))
+    (t (dtk-tone 500 30 'force)
+    (and emacspeak-delete-char-speak-deleted-char
+         (emacspeak-speak-char t))))
+    ad-do-it
+    (and emacspeak-delete-char-speak-current-char
+         (emacspeak-speak-char t)))
+   (t ad-do-it))
+  ad-return-value)
+
+(defadvice comint-send-eof (before emacspeak pre act comp)
+  "Announce what we are doing"
+(when (interactive-p)
+  (message "Sending EOF to subprocess")))
+
+(defadvice comint-accumulate  (before emacspeak pre act comp)
+  "Speak the line we are accumulating"
+  (when (interactive-p)
+    (save-excursion
+      (comint-bol-or-process-mark)
+      (emacspeak-auditory-icon 'select-object)
+      (emacspeak-speak-line 1))))
+    
+
+
+(defadvice comint-next-matching-input-from-input  (after
+                                                   emacspeak
+                                                   pre act com)
+"Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+(defadvice comint-previous-matching-input-from-input  (after
+                                                   emacspeak
+                                                   pre act com)
+"Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+
+
+(defadvice shell-forward-command (after emacspeak pre act
+                                        comp)
+  "Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+
+(defadvice shell-backward-command (after emacspeak pre act
+                                        comp)
+  "Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+
+(defadvice comint-show-output (after emacspeak pre act
+                                        comp)
+  "Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'large-movement))))
+
+(defadvice comint-show-maximum-output (after emacspeak pre act
+                                        comp)
+  "Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+
+(defadvice comint-bol-or-process-mark (after emacspeak pre act
+                                        comp)
+  "Speak the line showing where point is"
+(when (interactive-p)
+  (let ((emacspeak-show-point t)
+(voice-lock-mode t))
+(emacspeak-speak-line)
+(emacspeak-auditory-icon 'select-object))))
+
+
 (add-hook 'comint-mode-hook
           (function (lambda ()
                       (modify-syntax-entry 10 ">"  ))))
@@ -1166,6 +1266,12 @@ in completion buffers"
   (when (interactive-p)
     (emacspeak-auditory-icon 'fill-object )
     (message "Filled current paragraph")))
+
+(defadvice reindent-then-newline-and-indent (after emacspeak pre act comp)
+  "Provide auditory feedback to indicate indentation"
+  (when (interactive-p)
+    (emacspeak-speak-line)))
+
 (defadvice indent-relative (after emacspeak pre act comp)
   "Provide auditory feedback to indicate indentation"
   (when (interactive-p)
@@ -1253,6 +1359,24 @@ in completion buffers"
 ;;}}}
 ;;{{{  misc functions that have to be hand fixed:
 
+(defadvice undefined (after emacspeak pre act comp)
+  "Say that this is not defined"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'warn-user)
+(message "No command on this key")))
+
+(defadvice describe-mode (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (message "Displayed mode help in other window")
+    (emacspeak-auditory-icon 'help)))
+
+(defadvice describe-bindings (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (message "Displayed key bindings  in other window")
+    (emacspeak-auditory-icon 'help)))
+
 (defadvice indent-for-tab-command (after emacspeak pre act comp)
   "produce auditory feedback."
   (when (interactive-p)
@@ -1376,6 +1500,13 @@ in completion buffers"
   (when (interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
+(defadvice quit-window (after emacspeak pre act)
+  " Produce an auditory icon to indicate closing of an object.
+  Then indicate current buffer by speaking  the modeline." 
+  (when (interactive-p )
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-speak-mode-line)))
+
 
 (defadvice other-window (after emacspeak pre act )
   "Speak modeline.
@@ -1476,6 +1607,24 @@ become current"
     (read-command "To command:" ))))
 
 
+(defadvice help-next-ref (after emacspeak pre act comp)
+  "Speak the ref we moved to"
+(when (interactive-p)
+    (emacspeak-speak-text-range 'help-xref)
+    (emacspeak-auditory-icon 'large-movement)))
+
+(defadvice help-previous-ref (after emacspeak pre act comp)
+  "Speak the ref we moved to"
+  (when (interactive-p)
+    (emacspeak-speak-text-range 'help-xref)
+    (emacspeak-auditory-icon 'large-movement)))
+
+(defadvice help-follow (after emacspeak pre act comp)
+  "Speak the ref we moved to"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'button)))
+
 
 (defadvice describe-function (after emacspeak pre act)
   "Speak the help"
@@ -1644,25 +1793,49 @@ Otherwise cue user to the line just created. "
       (beginning-of-buffer)
       (emacspeak-speak-line))))
 
+
+(defadvice mail-text (after emacspeak pre act)
+  "Indicate movement"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
+  (emacspeak-speak-line )))
+
+
 (defadvice mail-subject (after emacspeak pre act)
   "Speak the subject line."
-  (emacspeak-speak-line ))
+  (when (interactive-p)
+  (emacspeak-speak-line )))
 
 (defadvice mail-cc   (after emacspeak pre act)
   "Speak the cc  line."
-  (emacspeak-speak-line ))
+  (when (interactive-p)
+    (emacspeak-speak-line )))
 
 (defadvice mail-bcc (after emacspeak pre act)
-  "Speak the subject line."
-  (emacspeak-speak-line ))
+  "Speak the bcc line."
+  (when (interactive-p)
+    (emacspeak-speak-line )))
 
 (defadvice mail-to (after emacspeak pre act)
-  "Speak the subject line."
-  (emacspeak-speak-line ))
+  "Speak the to line."
+  (when (interactive-p)
+  (emacspeak-speak-line )))
+
+
+(defadvice mail-reply-to (after emacspeak pre act)
+  "Speak the reply-to line."
+  (when (interactive-p)
+  (emacspeak-speak-line )))
+(defadvice mail-fcc (after emacspeak pre act)
+  "Speak the fcc line."
+  (when (interactive-p)
+  (emacspeak-speak-line )))
+
 
 (defadvice mail-signature  (after emacspeak pre act)
   "Announce you signed the message"
-  (message "Signed your message"))
+  (when (interactive-p)
+    (message "Signed your message")))
 
 (defadvice mail-send-and-exit (after emacspeak pre act)
   "Speak the modeline of active buffer."
@@ -1681,6 +1854,12 @@ Otherwise cue user to the line just created. "
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line )))
+(defadvice pop-tag-mark (after emacspeak pre act)
+  "Speak the line please. "
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-speak-line )))
+
 
 (defadvice tags-loop-continue (after emacspeak pre act)
   "Speak the line please. "
@@ -2021,6 +2200,21 @@ Pause ongoing speech first."
      'harry
      (emacspeak-speak-line nil ))))
 
+(defadvice isearch-delete-char (after emacspeak pre act)
+  "Speak the search hit.
+  Produce auditory icons if possible. "
+  (dtk-speak isearch-string)
+  (when (sit-for 0.5)
+    (emacspeak-auditory-icon 'search-hit)
+    (ems-set-personality-temporarily 
+     (point) 
+     (if  isearch-forward 
+         (- (point) (length isearch-string ))
+       (+ (point) (length isearch-string )))
+     'harry
+     (emacspeak-speak-line nil ))))
+
+
 (defadvice isearch-done (around emacspeak pre act comp)
   "Done searching --provide appropriate feedback"
   (let ((emacspeak-speak-messages-should-pause-ongoing-speech nil))
@@ -2349,11 +2543,103 @@ Do not change this unless you know what you are doing.")
     (emacspeak-speak-help)))
 
 ;;}}}
+;;{{{ speak context after done garbage collecting
+
+(defadvice garbage-collect (after emacspeak pre act comp)
+  "Speak modeline when done"
+  (when (interactive-p)
+    (emacspeak-speak-mode-line)
+    (emacspeak-auditory-icon 'select-object)))
+;;}}}
+;;{{{ copy-file rename-file and friends
+
+;;; file fileio.c defines these in a way 
+;;; that defeats our automatic advice for interactive
+;;; prompts.
+
+(defadvice copy-file (before fix-prompt pre act comp)
+  "Speak interactive prompts"
+  (interactive 
+   (list (read-file-name "Copy file: ")
+         (read-file-name "Copy to: "))))
+
+(defadvice rename-file (before fix-prompt pre act comp)
+  "Speak interactive prompts"
+  (interactive 
+   (list (read-file-name "Rename file: ")
+         (read-file-name "Rename to: "))))
+
+(defadvice add-name-to-file (before fix-prompt pre act comp)
+  "Speak interactive prompts"
+  (interactive 
+   (list (read-file-name "Add name to: ")
+         (read-file-name "Additional name: "))))
+
+(defadvice make-symbolic-link (before fix-prompt pre act comp)
+  "Speak interactive prompts"
+  (interactive 
+   (list (read-file-name "Symbolic link  source: ")
+         (read-file-name "Link Target: "))))
+
+;;}}}
+;;{{{ toggling debug state
+
+(defadvice toggle-debug-on-error (after emacspeak pre act comp)
+  "Produce an auditory icon"
+  (when (interactive-p)
+    (if debug-on-error 
+        (emacspeak-auditory-icon 'on)
+      nil
+      (emacspeak-auditory-icon 'off))
+    (message "Turned %s debug on error" debug-on-error)))
+
+(defadvice toggle-debug-on-quit (after emacspeak pre act comp)
+"Produce an auditory icon"
+(when (interactive-p)
+(if debug-on-error 
+(emacspeak-auditory-icon 'on)
+nil
+(emacspeak-auditory-icon 'off))
+(message "Turned %s debug on error"
+         debug-on-quit)))
+
+
+;;}}}
+;;{{{  Options mode and custom
+
+(defadvice customize (after emacspeak pre act comp)
+  "Provide status update"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-speak-mode-line)))
+
+(defadvice Edit-options-toggle (after emacspeak pre act
+                                      comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'button)))
+
+(defadvice Edit-options-t (after emacspeak pre act
+                                      comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'button)))
+
+(defadvice Edit-options-nil (after emacspeak pre act
+                                      comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'button)))
+;;}}}
 (provide 'emacspeak-advice)
 ;;{{{ end of file 
 
-;; local variables:
-;; folded-file: t
-;; end: 
+;;; local variables:
+;;; folded-file: t
+;;; byte-compile-dynamic: t
+;;; end: 
 
 ;;}}}
