@@ -1,5 +1,5 @@
 ;;; emacspeak-ediff.el --- Speech enable Emacs interface to diff and merge
-;;; $Id: emacspeak-ediff.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-ediff.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for ediff
 ;;; Keywords:emacspeak, audio interface to emacs, Comparing files 
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -41,6 +41,7 @@
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'backquote)
 (require 'emacspeak-speak)
+(require 'emacspeak-keymap)
 (require 'emacspeak-sounds)
 (require 'emacspeak-fix-interactive)
 (require 'voice-lock)
@@ -319,11 +320,14 @@ A.")
 (declaim (special ediff-auto-refine))
 (setq-default ediff-auto-refine 'on)
 
+  
+  
 (add-hook 'ediff-startup-hook
           (function (lambda ()
                       (declare (special ediff-mode-map
                                         voice-lock-mode))
-                        (setq voice-lock-mode t)
+                      (setq voice-lock-mode t)
+                      (emacspeak-keymap-remove-emacspeak-edit-commands ediff-mode-map)
                       (define-key ediff-mode-map "." 'emacspeak-ediff-speak-current-difference)
                       (emacspeak-ediff-voicify-differences))))
 
@@ -473,6 +477,7 @@ Set this to nil if things get too slow.")
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
