@@ -1,5 +1,5 @@
 ;;; emacspeak-gnus.el --- Speech enable GNUS -- Fluent spoken access to usenet
-;;; $Id: emacspeak-gnus.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-gnus.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Emacspeak extension to speech enable Gnus
 ;;; Keywords: Emacspeak, Gnus, Advice, Spoken Output, News
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -39,7 +39,9 @@
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (eval-when (compile) (require 'gnus)
+           (require 'gnus-sum)
            (require 'voice-lock)
+           (require 'emacspeak-keymap)
            (require 'emacspeak-fix-interactive))
 (require 'emacspeak-speak)
 
@@ -60,6 +62,17 @@
 
 
 ;;; Keybindings for summary mode:
+(and (boundp 'gnus-summary-mode-map)
+     (emacspeak-keymap-remove-emacspeak-edit-commands
+      gnus-summary-mode-map))
+
+(and (boundp 'gnus-article-mode-map)
+     (emacspeak-keymap-remove-emacspeak-edit-commands
+      gnus-article-mode-map))
+
+(and (boundp 'gnus-group-mode-map)
+     (emacspeak-keymap-remove-emacspeak-edit-commands
+      gnus-group-mode-map))
 
 (add-hook 'gnus-summary-mode-hook
           (function (lambda ()
@@ -68,7 +81,7 @@
                       (define-key gnus-summary-mode-map "T" 'gnus-summary-hide-all-headers )
                       (define-key gnus-summary-mode-map "t"
                         'gnus-summary-show-some-headers)
-                      (define-key gnus-summary-mode-map '[left] 'gnus-summary-catchup-quietly-and-exit)
+                      (define-key gnus-summary-mode-map '[left] 'gnus-summary-catchup-and-exit)
                       (define-key gnus-summary-mode-map '[right] 'gnus-summary-show-article))))
 
 (add-hook 'gnus-group-mode-hook
@@ -125,6 +138,17 @@ reading news."
   (emacspeak-dtk-sync)
   (dtk-speak (gnus-summary-subject-string )))
 
+;;}}}
+;;{{{ Advise top-level gnus command
+;;; emacs can hang if too many message sfly by as gnus starts
+(defadvice gnus (around emacspeak pre act )
+  "Temporarily deactivate advice on message"
+  (dtk-speak  "Starting gnus")
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it)
+  (emacspeak-auditory-icon 'news)
+  (message "Gnus is ready "))
+
 ;;}}}
 ;;{{{  starting up:
 
@@ -279,20 +303,15 @@ Produce an auditory icon if possible."
           ad-return-value )
       ad-return-value ))
 
-  (defadvice gnus-summary-catchup-and-exit (after emacspeak pre act)
-    "Speak the newsgroup line.
+(defadvice gnus-summary-catchup-and-exit (after emacspeak pre act)
+  "Speak the newsgroup line.
  Produce an auditory icon indicating 
 the previous group was closed."
-    (when (interactive-p)
-      (emacspeak-auditory-icon 'close-object)
-      (emacspeak-speak-line )))
-
-  (defun gnus-summary-catchup-quietly-and-exit nil
-    "Catch up on articles without confirmation. "
-    (interactive)
-    (gnus-summary-catchup-and-exit t t)
+  (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-line))
+    (emacspeak-speak-line )))
+
+  
 
   (defadvice gnus-summary-mark-as-unread-forward (after emacspeak pre act)
     "Speak the line.
@@ -559,6 +578,7 @@ instead you hear only the first screenful.")
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
