@@ -1,5 +1,5 @@
 ;;; emacspeak-imenu.el --- Speech enable Imenu -- produce buffer-specific table of contents
-;;; $Id: emacspeak-imenu.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-imenu.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Auditory interface buffer indices
 ;;; Keywords: Emacspeak, Speak, Spoken Output, indices
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -65,19 +65,64 @@
 ;;}}}
 ;;{{{  advise imenu to cache flattened alist
 
+(defun emacspeak-imenu-flatten-index-alist (index-alist &optional concat-names prefix)
+  ;; Takes a nested INDEX-ALIST and returns a flat index alist.
+  ;; If optional CONCAT-NAMES is non-nil, then a nested index has its
+  ;; name and a space concatenated to the names of the children.
+  ;; Third argument PREFIX is for internal use only.
+  (mapcan
+   (function
+    (lambda (item)
+      (let* ((name (car item))
+	     (pos (cdr item))
+	     (new-prefix (and concat-names
+			      (if prefix
+				  (concat prefix imenu-level-separator name)
+				name))))
+	(cond
+	 ((or (markerp pos) (numberp pos))
+	  (list (cons new-prefix pos)))
+	 (t
+	  (emacspeak-imenu-flatten-index-alist pos new-prefix))))))
+   index-alist))
+
 (defadvice imenu--make-index-alist (after emacspeak pre act comp)
   "Cache flattened index alist"
   (declare (special emacspeak-imenu-flattened-index-alist))
   (setq emacspeak-imenu-flattened-index-alist
-        (imenu--flatten-index-alist imenu--index-alist)))
+        (emacspeak-imenu-flatten-index-alist imenu--index-alist)))
 
 ;;}}}
 ;;{{{ advice 
 
 (defadvice imenu (after emacspeak pre act comp)
-"Provide auditory feedback"
-(when (interactive-p)
-(emacspeak-speak-line)))
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (ems-set-personality-temporarily (point) (1+ (point))
+                                     'paul-animated
+                                     (emacspeak-speak-line))))
+
+(defadvice imenu-go-find-at-position (around emacspeak pre act comp)
+  "Provide auditory feedback"
+  (cond
+   ((interactive-p)
+    (push-mark)
+    ad-do-it
+    (emacspeak-auditory-icon 'large-movement)
+    (ems-set-personality-temporarily (point) (1+ (point))
+                                     'paul-animated
+                                     (emacspeak-speak-line)))
+   (t ad-do-it))
+  ad-return-value)
+
+(defadvice imenu-go--back (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
+    (ems-set-personality-temporarily (point) (1+ (point))
+                                     'paul-animated
+                                     (emacspeak-speak-line))))
+
 
 ;;}}}
 ;;{{{  Navigation
@@ -94,7 +139,7 @@
         (target (point-max)))
     (unless emacspeak-imenu-flattened-index-alist
       (setq emacspeak-imenu-flattened-index-alist
-            (imenu--flatten-index-alist imenu--index-alist)))
+            (emacspeak-imenu-flatten-index-alist imenu--index-alist)))
     (loop for item  in emacspeak-imenu-flattened-index-alist
           do
           (setq guess
@@ -118,7 +163,7 @@
         (target (point-min)))
     (unless emacspeak-imenu-flattened-index-alist
       (setq emacspeak-imenu-flattened-index-alist
-            (imenu--flatten-index-alist imenu--index-alist)))
+            (emacspeak-imenu-flatten-index-alist imenu--index-alist)))
     (loop for item  in emacspeak-imenu-flattened-index-alist
           do
           (setq guess
@@ -157,11 +202,12 @@
 (setq imenu-space-replacement ".")
 
 ;;}}}
-(provide 'emacspeak-remote )
+(provide 'emacspeak-imenu )
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
