@@ -1,5 +1,5 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-pronounce.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -363,6 +363,16 @@ being defined")
          (define-key now-map  "\C-w"'emacspeak-pronounce-yank-word))
        now-map))))
 
+(defun emacspeak-pronounce-define-local-pronunciation (word  pronunciation )
+  "Define buffer local pronounciation. "
+  (interactive
+   (list
+    (emacspeak-pronounce-read-term 'buffer)
+    (read-from-minibuffer
+           (format "Pronounce  as: " ))))
+  (emacspeak-pronounce-add-buffer-local-dictionary-entry
+   word pronunciation))
+
 (defun emacspeak-pronounce-define-pronunciation ()
   "Interactively define entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
@@ -491,7 +501,8 @@ Activates pronunciation dictionaries if not already active."
   (let ((event (read-event)))
     (case event 
       (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
-      (?d (call-interactively 'emacspeak-pronounce-define-pronunciation))
+      (?d (call-interactively
+           'emacspeak-pronounce-define-pronunciation t))
       (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
       (?r (call-interactively 'emacspeak-pronounce-refresh-pronunciations))
       (?s (call-interactively 'emacspeak-pronounce-save-dictionaries))
@@ -505,6 +516,7 @@ Activates pronunciation dictionaries if not already active."
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
