@@ -1,5 +1,5 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-table-ui.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -65,6 +65,7 @@
   "Keymap for using in table browsing mode")
 
 (progn
+  (define-key emacspeak-table-keymap "q" 'emacspeak-kill-buffer-quietly)
   (define-key emacspeak-table-keymap "\t"
     'emacspeak-table-next-column)
   (define-key emacspeak-table-keymap  '[S-tab] 'emacspeak-table-previous-column)
@@ -900,6 +901,7 @@ markup to use."
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
