@@ -1,5 +1,5 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-tetris.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -171,9 +171,10 @@
   (interactive)
   (declare (special  tetris-pos-x tetris-pos-y
                      tetris-shape tetris-rot))
-  (message "%s at %s %s at rotation %s"
+  (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
-           tetris-pos-x tetris-pos-y
+tetris-pos-x
+           tetris-pos-y
            tetris-rot))
 
 (defsubst emacspeak-tetris-speak-score()
@@ -195,10 +196,14 @@
 ;;}}}
 ;;{{{  Advice
 
-(defvar emacspeak-tetris-tick-period 180
-  "*Set this to a convenient value so you get time to look at what is
-going on.
-Reduce it as you get better.")
+(defvar emacspeak-tetris-tick-period 15
+"*Set this to a convenient value so you get time to look at what is
+going on. Reduce it as you get better.")
+
+(defsubst emacspeak-tetris-tick-period ()
+  emacspeak-tetris-tick-period)
+
+(defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
 
 (defvar emacspeak-tetris-width tetris-width
   "*Set this to different values for fun")
@@ -315,6 +320,8 @@ compensate for the difference between aural and visual
 interaction.  Despite the clock being slowed down, playing
 Tetris with speech feedback alone requires a lot of
 concentration and the game is a good mental challenge. "
+  (declare (special tetris-tick-period
+                    emacspeak-tetris-blank-row))
   (when (interactive-p)
     (setq tetris-tick-period emacspeak-tetris-tick-period)
     (setq tetris-width emacspeak-tetris-width)
@@ -328,6 +335,7 @@ concentration and the game is a good mental challenge. "
 
 (defadvice tetris-start-game (after emacspeak pre act comp)
   "Provide auditory feedback"
+  (declare (special emacspeak-tetris-blank-row))
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (setq tetris-width emacspeak-tetris-width)
@@ -360,27 +368,28 @@ concentration and the game is a good mental challenge. "
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-x-coordinate)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-x-coordinate)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-x-coordinate)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-x-coordinate)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-x-coordinate)))
+    (emacspeak-tetris-speak-column)))
+
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
   "Provide auditory feedback as the tile falls"
   (when (interactive-p)
@@ -391,6 +400,9 @@ concentration and the game is a good mental challenge. "
   (when ad-return-value
     (emacspeak-auditory-icon 'item)))
 
+(defadvice tetris-draw-score (around emacspeak pre act comp)
+"dont draw the score"
+nil)
 ;;}}}
 ;;{{{  speak line 
 
@@ -400,6 +412,7 @@ concentration and the game is a good mental challenge. "
 (defun emacspeak-tetris-define-keys ()
   "Setup emacspeak tetris key bindings "
 (declare (special tetris-mode-map))
+(define-key tetris-mode-map "v" 'emacspeak-tetris-speak-column)
 (define-key tetris-mode-map "n" 'emacspeak-self-insert-command)
 (define-key tetris-mode-map "N" 'tetris-start-game)
 (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
@@ -435,9 +448,6 @@ concentration and the game is a good mental challenge. "
    (1+ tetris-height))
   (emacspeak-tetris-speak-row))
 
-
-
-
 (defvar emacspeak-tetris-blank-row
   (emacspeak-tetris-blank-row)
   "String matching a blank row of the board")
@@ -454,7 +464,7 @@ concentration and the game is a good mental challenge. "
   (forward-line 1)
   (emacspeak-tetris-speak-row))
 
-  (defun tetris-move-left-edge ()
+(defun tetris-move-left-edge ()
   "Moves the shape to the left edge  of the playing area"
   (interactive)
   (let ((hit nil))
@@ -507,11 +517,34 @@ concentration and the game is a good mental challenge. "
     (tetris-draw-shape)))
 
 ;;}}}
-(provide 'emacspeak-tetris)
+;;{{{ column browsing
+
+(defun emacspeak-tetris-get-column-contents (x)
+  "Return column contents as a string"
+  (declare (special tetris-height tetris-top-left-y
+                    tetris-top-left-x))
+  (let ((result nil))
+    (setq x (+ tetris-top-left-x x))
+    (setq result
+          (loop for y from tetris-top-left-y
+                to (+ tetris-height tetris-top-left-y)
+collect (gamegrid-get-cell x y)))
+(mapconcat 'char-to-string result "")))
+
+(defun emacspeak-tetris-speak-column (&optional x)
+  "Speak  column --default is to speak current column"
+  (interactive "p")
+  (declare (special tetris-pos-x))
+(or  x (setq x tetris-pos-x))
+(dtk-speak (emacspeak-tetris-get-column-contents x)))
+
+;;}}}
+(provide 'emacspeak-tetris)o
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
