@@ -1,13 +1,13 @@
 ;;; voice-lock.el --- Provide voice locking for Emacspeak
-;;; $Id: voice-lock.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: voice-lock.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Voice lock mode for Emacspeak
 ;;{{{  LCD Archive entry: 
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -175,9 +175,13 @@
 
     
 ;;{{{  first we pull in emacspeak additions
-
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
+(eval-when (compile)
+  (require 'emacspeak-sounds)
+  (require 'dtk-speak))
 (require 'voice-setup)
-  (require 'lazy-voice-lock)
+(require 'lazy-voice-lock)
 (require 'fast-voice-lock)
 (require 'regexp-opt)
 ;;}}}
@@ -313,6 +317,12 @@ The value should be like the `cdr' of an item in `voice-lock-defaults-alist'.")
 	   nil nil ((?_ . "w") (?~ . "w")) beginning-of-defun
 	   (voice-lock-comment-start-regexp . "/[*/]")
 	   (voice-lock-mark-block-function . mark-defun)))
+        (idl-mode-defaults
+	 '((c++-voice-lock-keywords c++-voice-lock-keywords-1 
+                                    c++-voice-lock-keywords-2 c++-voice-lock-keywords-3)
+	   nil nil ((?_ . "w") (?~ . "w")) beginning-of-defun
+	   (voice-lock-comment-start-regexp . "/[*/]")
+	   (voice-lock-mark-block-function . mark-defun)))
         (objc-mode-defaults
 	 '((objc-voice-lock-keywords objc-voice-lock-keywords-1
                                      objc-voice-lock-keywords-2 objc-voice-lock-keywords-3)
@@ -351,6 +361,7 @@ The value should be like the `cdr' of an item in `voice-lock-defaults-alist'.")
     (list
      (cons 'c++-c-mode			c-mode-defaults)
      (cons 'c++-mode			c++-mode-defaults)
+     (cons 'idl-mode			idl-mode-defaults)
      (cons 'c-mode			c-mode-defaults)
 (cons 'objc-mode			objc-mode-defaults)
      (cons 'java-mode			java-mode-defaults)
@@ -562,12 +573,13 @@ its mode hook."
       (voice-lock-unset-defaults))
     (force-mode-line-update))
   (when (interactive-p)
+    (when window-system (font-lock-mode voice-lock-mode))
     (dtk-speak
-   (format "Turned %s voice lock mode"
+     (format "Turned %s voice lock mode"
              (if voice-lock-mode "on" "off")))
-             (emacspeak-auditory-icon
-              (if voice-lock-mode
-                  'on 'off ))))
+    (emacspeak-auditory-icon
+     (if voice-lock-mode
+         'on 'off ))))
 
 ;;;###autoload
 (defun turn-on-voice-lock ()
@@ -2243,6 +2255,7 @@ See also `java-voice-lock-extra-types'.")
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
