@@ -1,13 +1,13 @@
 ;;; voice-settings.el --- Defines voice settings used to voice lock different modes
-;;; $Id: voice-settings.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: voice-settings.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Voice lock mode for Emacspeak
 ;;{{{  LCD Archive entry: 
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -38,6 +38,7 @@
 
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
+(eval-when-compile (load-library "cl-extra"))
 ;;{{{ flexible way of adding new voice lock modes:
 
 (defvar voice-lock-mode-specific-keywords-table
@@ -179,6 +180,7 @@ Return nil if not set."
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
