@@ -1,13 +1,13 @@
 ;;; voice-setup.el --- Setup voices for voice-lock
-;;; $Id: voice-setup.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: voice-setup.el,v 9.0 1998/10/24 05:17:28 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Voice lock mode for Emacspeak
 ;;{{{  LCD Archive entry: 
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@adobe.com 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1998/10/24 05:17:28 $ |
+;;;  $Revision: 9.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -92,6 +92,10 @@
   'harry 
   "Personality to use for function names.")
 
+(defvar voice-lock-warning-personality
+  'paul-angry
+  "Personality to use for function names.")
+
 (defvar voice-lock-keyword-personality
   'ursula  
   "Personality to use for keywords.")
@@ -136,6 +140,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
